@@ -23,7 +23,6 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
 #ifdef HAVE_CTYPE_H
    #include <ctype.h>
 #endif
@@ -80,14 +79,14 @@ int Decodedata_MakeConnectionList(CONNECTION data)
    char found = 0;
    CONNECTION *ptr;
 
-   sprintf(filter, "%c%s%d%s%d", data.proto, data.ip_source, data.source_port, data.ip_dest, data.dest_port);
+   sprintf(filter, "%c%s%d%s%d", data.proto, data.source_ip, data.source_port, data.dest_ip, data.dest_port);
 
    if (number_of_connections != 0)
    {
       for(ptr=Conn_Between_Hosts; num_conn <= number_of_connections; ptr++)
       {
-         sprintf(cur_conn, "%c%s%d%s%d", ptr->proto, ptr->ip_source, ptr->source_port, ptr->ip_dest, ptr->dest_port);
-         sprintf(rev_cur_conn, "%c%s%d%s%d", ptr->proto, ptr->ip_dest, ptr->dest_port, ptr->ip_source, ptr->source_port);
+         sprintf(cur_conn, "%c%s%d%s%d", ptr->proto, ptr->source_ip, ptr->source_port, ptr->dest_ip, ptr->dest_port);
+         sprintf(rev_cur_conn, "%c%s%d%s%d", ptr->proto, ptr->dest_ip, ptr->dest_port, ptr->source_ip, ptr->source_port);
 
          num_conn++;
 
@@ -148,7 +147,7 @@ int Decodedata_MakeConnectionList(CONNECTION data)
    if (!found)
    {
       #ifdef DEBUG
-         Debug_msg("Decodedata_MakeConnectionList - new node ! %d ! %c %s:%d - %s:%d ", num_conn, data.proto, data.ip_source, data.source_port, data.ip_dest, data.dest_port);
+         Debug_msg("Decodedata_MakeConnectionList - new node ! %d ! %c %s:%d - %s:%d ", num_conn, data.proto, data.source_ip, data.source_port, data.dest_ip, data.dest_port);
       #endif
 
       Conn_Between_Hosts = (CONNECTION *)realloc(Conn_Between_Hosts, num_conn*sizeof(CONNECTION));
@@ -157,11 +156,11 @@ int Decodedata_MakeConnectionList(CONNECTION data)
       else
          memset(&Conn_Between_Hosts[num_conn-1], 0, sizeof(CONNECTION));
 
-      memcpy(Conn_Between_Hosts[num_conn-1].ip_source, &data.ip_source, sizeof(data.ip_source));
-      memcpy(Conn_Between_Hosts[num_conn-1].ip_dest, &data.ip_dest, sizeof(data.ip_dest));
+      memcpy(Conn_Between_Hosts[num_conn-1].source_ip, &data.source_ip, sizeof(data.source_ip));
+      memcpy(Conn_Between_Hosts[num_conn-1].dest_ip, &data.dest_ip, sizeof(data.dest_ip));
 
-      Inet_PutMACinString(Conn_Between_Hosts[num_conn-1].mac_source, data.mac_source);
-      Inet_PutMACinString(Conn_Between_Hosts[num_conn-1].mac_dest, data.mac_dest);
+      Inet_PutMACinString(Conn_Between_Hosts[num_conn-1].source_mac, data.source_mac);
+      Inet_PutMACinString(Conn_Between_Hosts[num_conn-1].dest_mac, data.dest_mac);
 
       Conn_Between_Hosts[num_conn-1].source_port = data.source_port;
       Conn_Between_Hosts[num_conn-1].dest_port = data.dest_port;
@@ -265,7 +264,7 @@ void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
       }
 
       if (strlen(data->info) && !strchr(ptr->info, '\n'))
-         strlcat(ptr->info, data->info, 100);
+         strlcat(ptr->info, data->info, 150);
    }
    else
    {
