@@ -23,7 +23,6 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
@@ -42,8 +41,23 @@ typedef struct {
    int (*dissector)(u_char *, void *, int);
 } DISSECTOR;
 
-#define ALL_P -1
 
+typedef struct    // state machine double linked list for some protocol dissector
+{
+   long source_ip;
+   long dest_ip;
+   short source_port;
+   short dest_port;
+   char proto;
+   char state;
+   struct STATE_MACHINE *next;
+   struct STATE_MACHINE *prev;
+} STATE_MACHINE;
+
+
+STATE_MACHINE *SM_head;
+
+#define ALL_P -1
 
 static DISSECTOR Available_Dissectors[] = {
 
@@ -83,13 +97,15 @@ static DISSECTOR Available_Dissectors[] = {
    {MACBASED,  IPPROTO_TCP,  7777, &Dissector_napster},
    {MACBASED,  IPPROTO_TCP,  8080, &Dissector_http},     // for proxies
    {MACBASED,  IPPROTO_TCP,  8888, &Dissector_napster},
-   {MACBASED,  IPPROTO_UDP, ALL_P, &Dissector_icq},      // ICQv5 uses different server port
+//   {MACBASED,  IPPROTO_UDP, ALL_P, &Dissector_icq},      // ICQv5 uses different server port
 
                                           };
 
 // protos....
 
 void Dissector_Connections( char mode, short proto, u_char *data, void *data_to_ettercap, int Conn_Mode  );
+int Dissector_StateMachine_GetStatus(CONNECTION *data_to_ettercap);
+int Dissector_StateMachine_SetStatus(CONNECTION *data_to_ettercap, char status);
 int Dissector_base64decode(char *bufplain, const char *bufcoded);  // stolen from ap_base64.c part of apache source code
 
 // -------------------------------------
@@ -145,7 +161,106 @@ void Dissector_Connections( char mode, short proto, u_char *data, void *data_to_
    }
 }
 
-// lines below stolen from ap_base64.c ... ;)
+
+int Dissector_StateMachine_GetStatus(CONNECTION *data_to_ettercap)
+{
+   STATE_MACHINE *ptr = SM_head;
+
+   if (SM_head)
+      for(ptr = SM_head; ptr != NULL; ptr = (STATE_MACHINE *)ptr->next)
+          if ( ptr->proto == data_to_ettercap->proto &&
+               ((ptr->source_ip == inet_addr(data_to_ettercap->source_ip) &&     // straight
+                ptr->dest_ip == inet_addr(data_to_ettercap->dest_ip) &&
+                ptr->source_port == data_to_ettercap->source_port &&
+                ptr->dest_port == data_to_ettercap->dest_port)
+                ||
+                (ptr->source_ip == inet_addr(data_to_ettercap->dest_ip) &&       // reverse
+                ptr->dest_ip == inet_addr(data_to_ettercap->source_ip) &&
+                ptr->source_port == data_to_ettercap->dest_port &&
+                ptr->dest_port == data_to_ettercap->source_port))
+             )
+         {
+               return ptr->state;
+         }
+
+   return 0;
+}
+
+
+int Dissector_StateMachine_SetStatus(CONNECTION *data_to_ettercap, char status)
+{
+   STATE_MACHINE *index = SM_head;
+   STATE_MACHINE *ptr = index;
+   STATE_MACHINE *current;
+   char found = 0;
+
+   if (SM_head)
+   {
+      for(ptr = SM_head; ptr != NULL; ptr = (STATE_MACHINE *)ptr->next)
+      {
+         index = ptr;
+
+          if ( ptr->proto == data_to_ettercap->proto &&
+               ((ptr->source_ip == inet_addr(data_to_ettercap->source_ip) &&     // straight
+                ptr->dest_ip == inet_addr(data_to_ettercap->dest_ip) &&
+                ptr->source_port == data_to_ettercap->source_port &&
+                ptr->dest_port == data_to_ettercap->dest_port)
+                ||
+                (ptr->source_ip == inet_addr(data_to_ettercap->dest_ip) &&       // reverse
+                ptr->dest_ip == inet_addr(data_to_ettercap->source_ip) &&
+                ptr->source_port == data_to_ettercap->dest_port &&
+                ptr->dest_port == data_to_ettercap->source_port))
+             )
+         {
+            #ifdef DEBUG
+               Debug_msg("\tDissector_StateMachine_SetStatus - (%d)! ", status);
+            #endif
+            if (status)
+               ptr->state = status;
+            else
+            {
+               if (ptr->next) ((STATE_MACHINE *)ptr->next)->prev = (struct STATE_MACHINE *)ptr->prev;
+               if (ptr->prev) ((STATE_MACHINE *)ptr->prev)->next = (struct STATE_MACHINE *)ptr->next;
+               if (ptr == SM_head) SM_head = (STATE_MACHINE *)ptr->next;
+               free(ptr);
+            }
+            found = 1;
+            return 0;
+         }
+      }
+   }
+
+   if (!found)
+   {
+      #ifdef DEBUG
+         Debug_msg("\tDissector_StateMachine_SetStatus - new state (%d)! %c %s:%d - %s:%d ", status, data_to_ettercap->proto,
+                                                                                                     data_to_ettercap->source_ip,
+                                                                                                     data_to_ettercap->source_port,
+                                                                                                     data_to_ettercap->dest_ip,
+                                                                                                     data_to_ettercap->dest_port);
+      #endif
+
+      current = (STATE_MACHINE *)calloc(1, sizeof(STATE_MACHINE));
+      if (current == NULL)
+         Error_msg("ec_dissector:%d calloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+
+      current->source_ip = inet_addr(data_to_ettercap->source_ip);
+      current->dest_ip = inet_addr(data_to_ettercap->dest_ip);
+      current->source_port = data_to_ettercap->source_port;
+      current->dest_port = data_to_ettercap->dest_port;
+      current->proto = data_to_ettercap->proto;
+      current->state = status;
+
+      current->prev = (struct STATE_MACHINE *)index;
+      if (SM_head == NULL) SM_head = current;
+      if (index != NULL) index->next = (struct STATE_MACHINE *)current;
+   }
+
+   return 0;
+}
+
+
+// lines below stolen from ap_base64.c (apache source code)... ;)
 
 static const unsigned char pr2six[256] =
 {
