@@ -23,7 +23,6 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
 
 #include "include/ec_dissector.h"
 #include "include/ec_decodedata.h"
@@ -46,7 +45,6 @@ FUNC_DISSECTOR(Dissector_mysql)
    TCP_header *tcp;
    u_char *payload;
    u_char collector[MAX_DATA];
-   static char auth_step = 0;
    char seed[8];
    ONLY_CONNECTION;
 
@@ -59,7 +57,7 @@ FUNC_DISSECTOR(Dissector_mysql)
    memset(collector, 0, MAX_DATA);
    memcpy(collector, payload, data_to_ettercap->datalen);
 
-   if (!auth_step && ntohs(tcp->source) == 3306)            // server messages... collect the random seed
+   if ( (Dissector_StateMachine_GetStatus(data_to_ettercap) == 0) && ntohs(tcp->source) == 3306)            // server messages... collect the random seed
    {
       int i = 5;  // skip first five byte
 
@@ -75,10 +73,11 @@ FUNC_DISSECTOR(Dissector_mysql)
       strncpy(seed, collector + i + 1, 8);
       sprintf(data_to_ettercap->info, "Encrypted (one way) seed: %s  pass: ", seed);
 
-      auth_step = 1;
+      Dissector_StateMachine_SetStatus(data_to_ettercap, 1);
+      return 0;
    }
 
-   if ( (auth_step == 1) && ntohs(tcp->source) != 3306)  // client response crypt pass with seed
+   if ( (Dissector_StateMachine_GetStatus(data_to_ettercap) == 1) && ntohs(tcp->source) != 3306)  // client response crypt pass with seed
    {
       char user[25];
       char pass[25];
@@ -98,7 +97,7 @@ FUNC_DISSECTOR(Dissector_mysql)
       strcat(data_to_ettercap->info, "\n");
       sprintf(data_to_ettercap->type, "MySQL");
 
-      auth_step = 0;
+      Dissector_StateMachine_SetStatus(data_to_ettercap, 0);
     }
 
     return 0;
