@@ -25,7 +25,6 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
 #include <arpa/nameser.h>
 #include <openssl/ssl.h>
 #include <openssl/rand.h>
@@ -291,15 +290,15 @@ FUNC_DISSECTOR(Dissector_ssh)
    if (Conn_Mode)
    {
        datalen = data_to_ettercap->datalen;
-       IPS = inet_addr(data_to_ettercap->ip_source);
-       IPD = inet_addr(data_to_ettercap->ip_dest);
+       IPS = inet_addr(data_to_ettercap->source_ip);
+       IPD = inet_addr(data_to_ettercap->dest_ip);
        PORTS = data_to_ettercap->source_port;
        PORTD = data_to_ettercap->dest_port;
    }
    else
    {
-       IPS = inet_addr(sniff_data_to_ettercap->ip_source);
-       IPD = inet_addr(sniff_data_to_ettercap->ip_dest);
+       IPS = inet_addr(sniff_data_to_ettercap->source_ip);
+       IPD = inet_addr(sniff_data_to_ettercap->dest_ip);
        PORTS = sniff_data_to_ettercap->source_port;
        PORTD = sniff_data_to_ettercap->dest_port;
        datalen = sniff_data_to_ettercap->datasize;
@@ -556,9 +555,9 @@ FUNC_DISSECTOR(Dissector_ssh)
           put_bn((*index2)->myhostkey->n, &q);
 
           // Set the mask to 3DES
-          ptohl(payload+datalen-12) = htonl(8);
+          *(u_long *)(payload+datalen-12) = htonl(8);
           // recalculate SSH crc
-          ptohl(payload+datalen-4) = htonl(Inet_Forge_CRC(payload+4, datalen-8));
+          *(u_long *)(payload+datalen-4) = htonl(Inet_Forge_CRC(payload+4, datalen-8));
           // recalculate TCP checksum
           tcp->checksum = 0;
           tcp->checksum = Inet_Forge_Checksum((unsigned short *)tcp, IPPROTO_TCP, datalen+(tcp->doff * 4), IPS, IPD);
@@ -664,7 +663,7 @@ FUNC_DISSECTOR(Dissector_ssh)
           BN_clear_free(bn);
 
           // recalculate SSH crc
-          ptohl(payload+datalen-4) = htonl(Inet_Forge_CRC(payload+4, datalen-8));
+          *(u_long *)(payload+datalen-4) = htonl(Inet_Forge_CRC(payload+4, datalen-8));
           // recalculate TCP checksum
           tcp->checksum = 0;
           tcp->checksum = Inet_Forge_Checksum((unsigned short *)tcp, IPPROTO_TCP, datalen+(tcp->doff * 4), IPS, IPD);
