@@ -23,7 +23,6 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
@@ -46,23 +45,23 @@ FUNC_DISSECTOR(Dissector_vnc)
    TCP_header *tcp;
    u_char *payload;
    int major, minor, i;
-   static char handshake_step = 0;
    ONLY_CONNECTION;
 
    tcp = (TCP_header *) data;
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
-   if ( !handshake_step && sscanf(payload, "RFB %03d.%03d\n", &major, &minor) )
+   if ( (Dissector_StateMachine_GetStatus(data_to_ettercap) == 0) && sscanf(payload, "RFB %03d.%03d\n", &major, &minor) )
    {
       #ifdef DEBUG
          Debug_msg("\tDissector_VNC %d %d", major, minor);
       #endif
-      handshake_step = 1;
+      Dissector_StateMachine_SetStatus(data_to_ettercap, 1);
       return 0;
    }
 
-   if ( (handshake_step == 1) && ntohs(tcp->source) >= 5900 && ntohs(tcp->source) <= 5904 ) // this is the challenge from the server
+   if ( (Dissector_StateMachine_GetStatus(data_to_ettercap) == 1) &&
+    		ntohs(tcp->source) >= 5900 && ntohs(tcp->source) <= 5904 ) // this is the challenge from the server
    {
       sprintf(data_to_ettercap->user, "On display :%d\n", ntohs(tcp->source)-5900);
 
@@ -70,7 +69,7 @@ FUNC_DISSECTOR(Dissector_vnc)
       {
          strcat(data_to_ettercap->pass, "no pass required ;)\n");
          sprintf(data_to_ettercap->type, "VNC");
-         handshake_step = 0;  // finished
+         Dissector_StateMachine_SetStatus(data_to_ettercap, 0);  // finished
       }
 
       if (!memcmp(payload, "\x00\x02", 4))   // auth required
@@ -78,12 +77,12 @@ FUNC_DISSECTOR(Dissector_vnc)
          sprintf(data_to_ettercap->info, "Server Challenge: ");
          for (i = 0; i < 16; i++)
             sprintf(data_to_ettercap->info + (i * 2) + 18, "%.2x", payload[i+4]);
-         handshake_step = 2;
+         Dissector_StateMachine_SetStatus(data_to_ettercap, 2);
          return 0;
       }
    }
 
-   if (handshake_step == 2)      // this is the client 3DES encripted response
+   if (Dissector_StateMachine_GetStatus(data_to_ettercap) == 2)   // this is the client 3DES encripted response
    {
       strcat(data_to_ettercap->pass, "\n");
       sprintf(data_to_ettercap->info, " Client 3DES: ");
@@ -92,7 +91,7 @@ FUNC_DISSECTOR(Dissector_vnc)
 
       strcat(data_to_ettercap->info, "\n");
       sprintf(data_to_ettercap->type, "VNC");
-      handshake_step = 0;  // finished
+      Dissector_StateMachine_SetStatus(data_to_ettercap, 0);  // finished
    }
 
    return 0;
