@@ -24,7 +24,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include <errno.h>
 #include <signal.h>
 
 #include "include/ec_main.h"
@@ -192,8 +191,8 @@ int Illithid_ARPBased_GetData(char *iface, char proto, char *IPsource, int PortS
 
                if (ntohs(ip->frag_and_flags) & IP_OFFMASK) goto send;
 
-               strcpy(data_to_test.ip_source, int_ntoa(ip->source_ip) );
-               strcpy(data_to_test.ip_dest, int_ntoa(ip->dest_ip) );
+               strcpy(data_to_test.source_ip, int_ntoa(ip->source_ip) );
+               strcpy(data_to_test.dest_ip, int_ntoa(ip->dest_ip) );
                data_to_test.source_port = ntohs(udp->source);
                data_to_test.dest_port = ntohs(udp->dest);
                data = (char *)((int)udp + UDP_HEADER);
@@ -202,13 +201,13 @@ int Illithid_ARPBased_GetData(char *iface, char proto, char *IPsource, int PortS
                {
                   datalen = ntohs(udp->len) - UDP_HEADER;
 
-                  if (ok == 1)
+                  if (ok == 1)	// from source
                   {
                      len -= ETH_HEADER;
                      delta = FilterDrop_MakefilterUDP((u_char *)ip, &len, MTU-40, &ARP_Filter_Source);
                      len += ETH_HEADER;
                   }
-                  else // ok == 2
+                  else // ok == 2   from dest
                   {
                      len -= ETH_HEADER;
                      delta = FilterDrop_MakefilterUDP((u_char *)ip, &len, MTU-40, &ARP_Filter_Dest);
@@ -225,8 +224,8 @@ int Illithid_ARPBased_GetData(char *iface, char proto, char *IPsource, int PortS
 
                if (ntohs(ip->frag_and_flags) & IP_OFFMASK) goto send;
 
-               strcpy(data_to_test.ip_source, int_ntoa(ip->source_ip) );
-               strcpy(data_to_test.ip_dest, int_ntoa(ip->dest_ip) );
+               strcpy(data_to_test.source_ip, int_ntoa(ip->source_ip) );
+               strcpy(data_to_test.dest_ip, int_ntoa(ip->dest_ip) );
                data_to_test.source_port = ntohs(tcp->source);
                data_to_test.dest_port = ntohs(tcp->dest);
 
@@ -498,13 +497,13 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
    Inet_GetIfaceInfo( iface, &MTU, MyMAC, &IP_Test, &NetMask);
 
    if (mode > PUBLICARP)
-       Inet_SetPromisc(iface);
+      Inet_SetPromisc(iface);
    else
       IP_Test=IP_Test&NetMask;
 
    buffer = Inet_Forge_packet(MTU);
 
-   for (;;)
+   loop
    {
       if (getppid() == 1) exit(0);
 
@@ -520,7 +519,7 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
          char ok1 = 0;
 
          eth = (ETH_header *)buffer;
-         memcpy(data_to_ettercap.mac_source,eth->source_mac,6);
+         memcpy(data_to_ettercap.source_mac,eth->source_mac,6);
 
          if (mode == MACBASED)
          {
@@ -533,10 +532,10 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
          {
             ip = (IP_header *)(eth+1);
 
-            strcpy(data_to_ettercap.ip_source, int_ntoa(ip->source_ip) );
-            strcpy(data_to_ettercap.ip_dest, int_ntoa(ip->dest_ip) );
-            strcpy(sniff_data_to_ettercap.ip_source, int_ntoa(ip->source_ip) );
-            strcpy(sniff_data_to_ettercap.ip_dest, int_ntoa(ip->dest_ip) );
+            strcpy(data_to_ettercap.source_ip, int_ntoa(ip->source_ip) );
+            strcpy(data_to_ettercap.dest_ip, int_ntoa(ip->dest_ip) );
+            strcpy(sniff_data_to_ettercap.source_ip, int_ntoa(ip->source_ip) );
+            strcpy(sniff_data_to_ettercap.dest_ip, int_ntoa(ip->dest_ip) );
 
             if ( mode == IPBASED && Illithid_ToBeSniffed_ip(IP1p, IP2p, &data_to_ettercap) ) ok1 = 1;
 
@@ -558,14 +557,14 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
 
             if (mode == PUBLICARP && !Act_Connection_Mode) ok1 = 1;
 
-            if ( mode == PUBLICARP && !strcmp(data_to_ettercap.ip_dest,IP1p))
+            if ( mode == PUBLICARP && !strcmp(data_to_ettercap.dest_ip,IP1p))
             {
                memcpy(eth->dest_mac, MAC1, 6);
                memcpy(eth->source_mac, MyMAC, 6);
                ok1 = 1;
             }
             else
-            if ( mode == PUBLICARP && !strcmp(data_to_ettercap.ip_dest,IP2p))
+            if ( mode == PUBLICARP && !strcmp(data_to_ettercap.dest_ip,IP2p))
             {
                memcpy(eth->dest_mac, MAC2, 6);
                memcpy(eth->source_mac, MyMAC, 6);
@@ -583,7 +582,7 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
                ok1 = 1;
             }
 
-            memcpy(data_to_ettercap.mac_dest,eth->dest_mac,6);
+            memcpy(data_to_ettercap.dest_mac,eth->dest_mac,6);
 
             if ( ok1 && ip->proto == IPPROTO_TCP)
             {
@@ -663,7 +662,8 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
             if (mode <= PUBLICARP && ok1 && Act_Connection_Mode) Inet_SendRawPacket(sock, buffer, len);
          }
       }
-   }
+
+   } // end loop
 }
 
 
@@ -676,19 +676,19 @@ int Illithid_ToBeSniffed(char *source, int psource, char *dest, int pdest, SNIFF
    if (!strcmp(source, "") || !strcmp(source, "0.0.0.0") ) s = 1;
    if (!strcmp(dest, "") || !strcmp(dest, "0.0.0.0")) d = 1;
 
-   if (s || !strcmp(source, data->ip_source))
+   if (s || !strcmp(source, data->source_ip))
       if (ps || psource == data->source_port)
       {  s = 1;   ps = 1;  }
 
-   if (s || !strcmp(source, data->ip_dest))
+   if (s || !strcmp(source, data->dest_ip))
       if (ps || psource == data->dest_port)
       {  s = 1;   ps = 1;  }
 
-   if (d || !strcmp(dest, data->ip_source))
+   if (d || !strcmp(dest, data->source_ip))
       if (pd || pdest == data->source_port)
       {  d = 1;   pd = 1;  }
 
-   if (d || !strcmp(dest, data->ip_dest))
+   if (d || !strcmp(dest, data->dest_ip))
       if (pd || pdest == data->dest_port)
       {  d = 1;   pd = 1;  }
 
@@ -703,13 +703,13 @@ int Illithid_ToBeSniffed_ip(char *source, char *dest, CONNECTION *data)
    if (!strcmp(source, "")) s = 1;
    if (!strcmp(dest, "")) d = 1;
 
-   if (s || !strcmp(source, data->ip_source)) s = 1;
+   if (s || !strcmp(source, data->source_ip)) s = 1;
 
-   if (s || !strcmp(source, data->ip_dest)) s = 1;
+   if (s || !strcmp(source, data->dest_ip)) s = 1;
 
-   if (d || !strcmp(dest, data->ip_source)) d = 1;
+   if (d || !strcmp(dest, data->source_ip)) d = 1;
 
-   if (d || !strcmp(dest, data->ip_dest)) d = 1;
+   if (d || !strcmp(dest, data->dest_ip)) d = 1;
 
    return ( s && d );
 
