@@ -26,7 +26,6 @@
 #include <sys/ioctl.h>
 #include <fcntl.h>
 #include <signal.h>
-#include <errno.h>
 
 #include "include/ec_main.h"
 #include "include/ec_error.h"
@@ -68,7 +67,7 @@ void Inet_Free_list(host_list *head);
 host_list *Inet_Host_in_LAN_list(char *interface);
 SniffingHost *Inet_NoSniff(void);
 void Inet_PutMACinString(char *mac_string, unsigned char *MAC);
-void Inet_GetMACfromString(char *mac_string, unsigned char *MAC);
+int Inet_GetMACfromString(char *mac_string, unsigned char *MAC);
 int Inet_Fake_Host(void);
 int Inet_CheckSwitch(void);
 // Following are architecture dependent !! implementations are in ./src/`uname`/ec_inet_`uname`.c
@@ -108,10 +107,16 @@ char * Inet_HostName(char *ip)   // returns hostname from ip
    struct hostent *host;
    static struct in_addr addr;
 
-   addr.s_addr = inet_addr(ip);
-   host = gethostbyaddr((char *)&addr, sizeof(struct in_addr), AF_INET);
-
-   if (host != NULL) return (char *) host->h_name;
+   if (!Options.dontresolve)
+   {
+      addr.s_addr = inet_addr(ip);
+      host = gethostbyaddr((char *)&addr, sizeof(struct in_addr), AF_INET);
+      #ifdef DEBUG
+         if (host != NULL) Debug_msg("Inet_HostName -- [%s]", (char *) host->h_name);
+         else Debug_msg("Inet_HostName -- [NOT resolved...]");
+      #endif
+      if (host != NULL) return (char *) host->h_name;
+   }
 
    return "Unknown host";
 }
@@ -141,32 +146,31 @@ char * Inet_GetMyInfo(char tipo)
    static char MySubnet[16];
    static char IP[16];
 
-#ifdef DEBUG
-   switch (tipo)
-   {
-      case 0: Debug_msg("Inet_GetMyInfo IP"); break;
-      case 1: Debug_msg("Inet_GetMyInfo MAC"); break;
-      case 2: Debug_msg("Inet_GetMyInfo NetMask"); break;
-   }
-#endif
-
    Inet_GetIfaceInfo(Options.netiface, NULL, MAC_Add, &IP_Add, &NetMask);
 
-
    switch (tipo)
    {
          case 0:  // requesting IP
                   sprintf(IP, "%s", int_ntoa(IP_Add));
+                  #ifdef DEBUG
+                     Debug_msg("Inet_GetMyInfo IP -- [%s]", IP);
+                  #endif
                   return IP;
                   break;
 
          case 1:  // requesting MAC
                   Inet_PutMACinString( MAC, MAC_Add );
+                  #ifdef DEBUG
+                     Debug_msg("Inet_GetMyInfo MAC -- [%s]", MAC);
+                  #endif
                   return MAC;
                   break;
 
          case 2:  // requesting netmask
                   sprintf(MySubnet, "%s", int_ntoa(NetMask));
+                  #ifdef DEBUG
+                     Debug_msg("Inet_GetMyInfo NetMask -- [%s]", MySubnet);
+                  #endif
                   return MySubnet;
                   break;
    }
@@ -214,6 +218,9 @@ int Inet_HostInLAN()
    for( ; index; host_alive++)
       index = (host_list *)index->next;
 
+   if (!Options.dontresolve && !Host_In_LAN)
+      fprintf(stdout, "Resolving %d hostnames...\n", host_alive);
+
    if (Host_In_LAN) free(Host_In_LAN);
    Host_In_LAN = (HOST *)calloc(host_alive,sizeof(HOST));
    if (Host_In_LAN == NULL)
@@ -275,56 +282,64 @@ host_list *Inet_Host_in_LAN_list(char *interface)
    N_hosts = ntohl(~NetMask);
 
 #ifdef DEBUG
-   Debug_msg("Inet_HostInLAN_list -- netmask 0x%0x  hosts %d", NetMask, N_hosts);
+   Debug_msg("Inet_HostInLAN_list -- netmask 0x%0x  hosts %d", htonl(NetMask), N_hosts);
 #endif
 
    if (Options.broadping)
    {
 
-         BroadAdd = head->IP_Add | (~NetMask);
-         buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
-         Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_IP );
+      BroadAdd = head->IP_Add | (~NetMask);
 
-         Inet_Forge_ip( buf + ETH_HEADER,
-                        head->IP_Add,
-                        BroadAdd,
-                        sizeof(ICMP_header),
-                        0xe77e,
-                        0,
-                        IPPROTO_ICMP );
+      if (!Host_In_LAN)
+         fprintf(stdout, "Sending broadcast ping to %s...\n", int_ntoa(BroadAdd));
 
-         Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
-         Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
-         Inet_Forge_packet_destroy( buf );
+
+      buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
+      Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_IP );
+
+      Inet_Forge_ip( buf + ETH_HEADER,
+                     head->IP_Add,
+                     BroadAdd,
+                     sizeof(ICMP_header),
+                     0xe77e,
+                     0,
+                     IPPROTO_ICMP );
+
+      Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
+      Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
+      Inet_Forge_packet_destroy( buf );
 
    }
    else // !broadping
    {
 
-         buf = Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
+      if (!Host_In_LAN)
+         fprintf(stdout, "Sending %d ARP request...\n", N_hosts);
 
-         // frame ethernet header
-         Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_ARP );
+      buf = Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
 
-         for (index=1; index<=N_hosts; index++)
+      // frame ethernet header
+      Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_ARP );
+
+      for (index=1; index<=N_hosts; index++)
+      {
+         int dest_ip;
+         dest_ip = (head->IP_Add&NetMask)|htonl(index);
+
+         // if dest is equal to me
+         if (dest_ip != head->IP_Add)
          {
-            int dest_ip;
-            dest_ip = (head->IP_Add&NetMask)|htonl(index);
+            // arp request
+            Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REQUEST,
+                            head->MAC_Add, head->IP_Add,
+                            ARP_BROADCAST, dest_ip );
 
-            // if dest is equal to me
-            if (dest_ip != head->IP_Add)
-            {
-               // arp request
-               Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REQUEST,
-                               head->MAC_Add, head->IP_Add,
-                               ARP_BROADCAST, dest_ip );
-
-               Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
-            }
-            usleep(500);
+            Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
          }
+         usleep(500);
+      }
 
-         Inet_Forge_packet_destroy( buf );
+      Inet_Forge_packet_destroy( buf );
 
    }
 
@@ -332,6 +347,9 @@ host_list *Inet_Host_in_LAN_list(char *interface)
    Debug_msg("Inet_HostInLAN_list -- listening for replies...");
 #endif
 
+   if (!Host_In_LAN)
+      fprintf(stdout, "Listening for replies...\n");
+
    fcntl(sock, F_SETFL, O_NONBLOCK);
 
    TIME_START;
@@ -378,7 +396,7 @@ host_list *Inet_Host_in_LAN_list(char *interface)
                   }
                }
             }
-         } while ( TIME_ELAPSED < 1 );
+         } while ( TIME_ELAPSED < 2 );
 
    }
    else  // !broadping
@@ -419,10 +437,14 @@ host_list *Inet_Host_in_LAN_list(char *interface)
                   memcpy((char *)&((*index)->IP_Add), arppkt->source_ip, 4);
                }
             }
-         } while ( TIME_ELAPSED < 1.5 );
+         } while ( TIME_ELAPSED < 2 );
 
    }
 
+   #ifdef DEBUG
+      Debug_msg("Inet_HostInLAN_list -- waiting timed out after %.5f seconds", TIME_ELAPSED );
+   #endif
+
    Inet_Forge_packet_destroy( buf );
    close(sock);
    return head;
@@ -668,22 +690,33 @@ int Inet_CheckSwitch()
 
 
 
-void Inet_GetMACfromString(char *mac_string, unsigned char *MAC)
+int Inet_GetMACfromString(char *mac_string, unsigned char *MAC)
 {
    unsigned int MAC_Add[6];
-   int i;
+   int i, j=0;
+
+   for(i=0; i<strlen(mac_string); i++)
+      if (mac_string[i] == ':')
+         j++;
+
+   if (j < 5)     // bad mac string
+      return -1;
 
    memset(&MAC_Add, 0, 6);
 
+   i=0;
+
    i = sscanf(mac_string,"%02X:%02X:%02X:%02X:%02X:%02X",
       (unsigned int *)&MAC_Add[0],(unsigned int *)&MAC_Add[1],(unsigned int *)&MAC_Add[2],
       (unsigned int *)&MAC_Add[3],(unsigned int *)&MAC_Add[4],(unsigned int *)&MAC_Add[5]);
 
-   if (i == 0)
-      Error_msg("Incorrect parsing of MAC [%s] !!\nIt must be in the form 01:02:03:04:05:06 !!", mac_string);
+   if (i == 0) // bad mac string
+      return -1;
 
    for (i=0; i<6; i++)
       MAC[i]=(unsigned char)MAC_Add[i];
+
+   return 0;
 }
 
 
