@@ -30,6 +30,7 @@
 #include <signal.h>
 
 #include "include/ec_interface_sniff.h"
+#include "include/ec_interface_factory.h"
 #include "include/ec_inet.h"
 #include "include/ec_buffer.h"
 #include "include/ec_fingerprint.h"
@@ -47,6 +48,8 @@
 
 #define DOWN   +1             // movements for the pointer
 #define UP     -1
+#define RIGHT  +1
+#define LEFT   -1
 
 #define BOTTOM_COLOR 1        // color schemes
 #define TITLE_COLOR  2
@@ -74,7 +77,7 @@ void Interface_Redraw(void);
 void Interface_WExit(char *buffer);
 void Interface_Run(void);
 void Interface_GetWindowSize();
-void Interface_PointItem(char direction);
+void Interface_PointItem(char direction, char hor_direction);
 void Interface_InitList(void);
 void Interface_KeyTab(void);
 void Interface_SelectItem(void);
@@ -390,7 +393,7 @@ void Interface_InitList(void)
 
 
 
-void Interface_PointItem(char direction)
+void Interface_PointItem(char direction, char hor_direction)
 {
 
    int Old_Pointer;
@@ -424,22 +427,32 @@ void Interface_PointItem(char direction)
    else
       wattroff(main_window,A_REVERSE);
 
+	if (hor_direction)
+	{
+		switch(hor_direction)
+		{
+			case LEFT:
+					      if (Pointer == &Dest_Pointer)
+      					{
+			      			Pointer = &Source_Pointer;
+			      			*Pointer = Dest_Pointer;
+			      		}
+							break;
+			case RIGHT:
+					      if (Pointer == &Source_Pointer)
+      					{
+								Pointer = &Dest_Pointer;
+								*Pointer = Source_Pointer;
+							}
+							break;
+		}
+	}
 
    if ( (Old_Pointer >= Base_Pointer) && (Old_Pointer <= Base_Pointer + Sel_Number -1))   // DON'T redraw previous selected item if it is out of view
    {
-
-      if (Pointer == &Source_Pointer)
-      {
-         wmove(main_window, Old_Pointer - Base_Pointer, W_LIST_SOURCE);
-         whline(main_window,' ',W_MAINX2 - 1);                          //deletes the previous position
-         wprintw(main_window, "%3d) %15s      %3d) %15s", Old_Pointer+1, Host_In_LAN[Old_Pointer].ip, Old_Pointer+1, Host_In_LAN[Old_Pointer].ip);
-      }
-      else if (Pointer == &Dest_Pointer)
-      {
-         wmove(main_window, Old_Pointer - Base_Pointer, W_LIST_DEST );
-         whline(main_window,' ',W_MAINX2 - 1);                          //deletes the previous position
-         wprintw(main_window, " %3d) %15s", Old_Pointer+1, Host_In_LAN[Old_Pointer].ip);
-      }
+      wmove(main_window, Old_Pointer - Base_Pointer, W_LIST_SOURCE);
+      whline(main_window,' ',W_MAINX2 - 1);                          //deletes the previous position
+      wprintw(main_window, "%3d) %15s      %3d) %15s", Old_Pointer+1, Host_In_LAN[Old_Pointer].ip, Old_Pointer+1, Host_In_LAN[Old_Pointer].ip);
    }
 
    if (has_colors())
@@ -981,19 +994,27 @@ void Interface_Run(void)
       switch (KeyPress)
       {
          case KEY_DOWN:
-                  Interface_PointItem(DOWN);
+                  Interface_PointItem(DOWN, 0);
                   break;
 
          case KEY_UP:
-                  Interface_PointItem(UP);
+                  Interface_PointItem(UP, 0);
+                  break;
+
+         case KEY_LEFT:
+                  Interface_PointItem(0, LEFT);
+                  break;
+
+         case KEY_RIGHT:
+                  Interface_PointItem(0, RIGHT);
                   break;
 
          case KEY_NPAGE:
-                  Interface_PointItem(Sel_Number-1);  //PGDOWN
+                  Interface_PointItem(Sel_Number-1, 0);  //PGDOWN
                   break;
 
          case KEY_PPAGE:
-                  Interface_PointItem(-Sel_Number+1); //PGUP
+                  Interface_PointItem(-Sel_Number+1, 0); //PGUP
                   break;
 
          case KEY_TAB:
@@ -1038,6 +1059,12 @@ void Interface_Run(void)
                   memset(&Host_Dest, 0, sizeof(HOST));
                   break;
 
+         case 'X':
+         case 'x':
+                  Interface_Factory_Run();
+                  Interface_Redraw();
+                  break;
+
 #ifdef PERMIT_PLUGINS
          case 'P':
          case 'p':
@@ -1059,11 +1086,12 @@ void Interface_Run(void)
                         "             . for man-in-the-middle technique",
                         "[sS]      - IP based sniffing",
                         "[mM]      - MAC based sniffing",
+                        "[xX]      - Packet Forge",
 #ifdef PERMIT_PLUGINS
                         "[pP]      - run a plugin",
 #endif
-                        "[cC]      - check for other poisoner...",
                         "[fF]      - OS fingerprint",
+                        "[cC]      - check for other poisoner...",
                         "[rR]      - refresh the list",
                         "[hH]      - this help screen",
                         NULL};
@@ -1100,7 +1128,7 @@ void Interface_Run(void)
                   #ifdef DEBUG
                      Debug_msg("Interface_Run_END");
                   #endif
-                  Interface_WExit("Quitting... ");
+                  Interface_WExit("");
                   break;
 
          default:
@@ -1138,6 +1166,8 @@ void Interface_WExit(char *buffer)
 
    if (ScreenMode) Interface_CloseScreen();
 
+	printf("\033[01m\033[1m%s %s brought from the dark side of the net by ALoR and NaGA...\033[0m\n\n", PROGRAM, VERSION);
+	printf("\033[01m\033[1mmay the packets be with you...\033[0m\n\n");
    printf("\n");
    printf(buffer);
    printf("\n\n");
