@@ -30,6 +30,7 @@
 
 #include "include/ec_interface.h"
 #include "include/ec_interface_sniff_data.h"
+#include "include/ec_interface_factory.h"
 #include "include/ec_decodedata.h"
 #include "include/ec_illithid.h"
 #include "include/ec_doppleganger.h"
@@ -42,6 +43,10 @@
    #include "include/ec_debug.h"
 #endif
 
+#ifdef PERMIT_PLUGINS
+   #include "include/ec_interface_plugins.h"
+   #include "include/ec_plugins.h"
+#endif
 
 #define BOTTOM_COLOR 1        // color schemes
 #define TITLE_COLOR  2
@@ -110,8 +115,8 @@ void Interface_Sniff_InitList(void)
    for(j=Conn_Base_Pointer; j<Conn_Top_Pointer; j++)     // prints connections within the main_window height
    {
       wmove(main_window, j-Conn_Base_Pointer, LeftMargin );
-      wprintw(main_window, "%3d) %15s:%d", j+1, Conn_Between_Hosts[j].ip_source, Conn_Between_Hosts[j].source_port);
-      mvwprintw(main_window, j-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[j].ip_dest , Conn_Between_Hosts[j].dest_port);
+      wprintw(main_window, "%3d) %15s:%d", j+1, Conn_Between_Hosts[j].source_ip, Conn_Between_Hosts[j].source_port);
+      mvwprintw(main_window, j-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[j].dest_ip , Conn_Between_Hosts[j].dest_port);
       wmove(main_window, j-Conn_Base_Pointer, LeftMargin + 56);  waddch(main_window, ACS_VLINE);
       wprintw(main_window, " %s", Conn_Between_Hosts[j].status);
       wmove(main_window, j-Conn_Base_Pointer, LeftMargin + 65);  waddch(main_window, ACS_VLINE);
@@ -126,8 +131,8 @@ void Interface_Sniff_InitList(void)
 
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin );
    whline(main_window, ' ', W_SELECTCONN);
-   wprintw(main_window, "%3d) %15s:%d", Conn_Pointer+1, Conn_Between_Hosts[Conn_Pointer].ip_source, Conn_Between_Hosts[Conn_Pointer].source_port);
-   mvwprintw(main_window, Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Conn_Pointer].ip_dest , Conn_Between_Hosts[Conn_Pointer].dest_port);
+   wprintw(main_window, "%3d) %15s:%d", Conn_Pointer+1, Conn_Between_Hosts[Conn_Pointer].source_ip, Conn_Between_Hosts[Conn_Pointer].source_port);
+   mvwprintw(main_window, Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Conn_Pointer].dest_ip , Conn_Between_Hosts[Conn_Pointer].dest_port);
    wmove(main_window, Conn_Pointer-Conn_Base_Pointer, LeftMargin + 56);  waddch(main_window, ACS_VLINE);
    wprintw(main_window, " %s", Conn_Between_Hosts[Conn_Pointer].status);
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin + 65); waddch(main_window, ACS_VLINE);
@@ -189,8 +194,8 @@ void Interface_Sniff_PointItem(char direction)
       wmove(main_window, Old_Conn_Pointer - Conn_Base_Pointer, LeftMargin);
       whline(main_window,' ', W_SELECTCONN);                         //deletes the previous position
 
-      wprintw(main_window, "%3d) %15s:%d", Old_Conn_Pointer+1, Conn_Between_Hosts[Old_Conn_Pointer].ip_source, Conn_Between_Hosts[Old_Conn_Pointer].source_port);
-      mvwprintw(main_window, Old_Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Old_Conn_Pointer].ip_dest , Conn_Between_Hosts[Old_Conn_Pointer].dest_port);
+      wprintw(main_window, "%3d) %15s:%d", Old_Conn_Pointer+1, Conn_Between_Hosts[Old_Conn_Pointer].source_ip, Conn_Between_Hosts[Old_Conn_Pointer].source_port);
+      mvwprintw(main_window, Old_Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Old_Conn_Pointer].dest_ip , Conn_Between_Hosts[Old_Conn_Pointer].dest_port);
       wmove(main_window, Old_Conn_Pointer - Conn_Base_Pointer, LeftMargin + 56);  waddch(main_window, ACS_VLINE);
       wprintw(main_window, " %s", Conn_Between_Hosts[Old_Conn_Pointer].status);
       wmove(main_window, Old_Conn_Pointer - Conn_Base_Pointer, LeftMargin + 65);  waddch(main_window, ACS_VLINE);
@@ -205,8 +210,8 @@ void Interface_Sniff_PointItem(char direction)
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin);
    whline(main_window, ' ', W_SELECTCONN);                           //select new position
 
-   wprintw(main_window, "%3d) %15s:%d", Conn_Pointer+1, Conn_Between_Hosts[Conn_Pointer].ip_source, Conn_Between_Hosts[Conn_Pointer].source_port);
-   mvwprintw(main_window, Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Conn_Pointer].ip_dest , Conn_Between_Hosts[Conn_Pointer].dest_port);
+   wprintw(main_window, "%3d) %15s:%d", Conn_Pointer+1, Conn_Between_Hosts[Conn_Pointer].source_ip, Conn_Between_Hosts[Conn_Pointer].source_port);
+   mvwprintw(main_window, Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Conn_Pointer].dest_ip , Conn_Between_Hosts[Conn_Pointer].dest_port);
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin + 56);  waddch(main_window, ACS_VLINE);
    wprintw(main_window, " %s", Conn_Between_Hosts[Conn_Pointer].status);
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin + 65);  waddch(main_window, ACS_VLINE);
@@ -278,19 +283,19 @@ void Interface_Sniff_KillConn(void)
 
 
 #ifdef DEBUG
-   Debug_msg("Interface_Sniff_KillConn -- %s:%d -> %s:%d  %lu %lu", Conn_Between_Hosts[Conn_Pointer].ip_source,
+   Debug_msg("Interface_Sniff_KillConn -- %s:%d -> %s:%d  %lu %lu", Conn_Between_Hosts[Conn_Pointer].source_ip,
                                                                     Conn_Between_Hosts[Conn_Pointer].source_port,
-                                                                    Conn_Between_Hosts[Conn_Pointer].ip_dest,
+                                                                    Conn_Between_Hosts[Conn_Pointer].dest_ip,
                                                                     Conn_Between_Hosts[Conn_Pointer].dest_port,
                                                                     Conn_Between_Hosts[Conn_Pointer].source_seq,
                                                                     Conn_Between_Hosts[Conn_Pointer].dest_seq );
 #endif
 
    Inet_GetMACfromString(Inet_MyMACAddress(), MACS);
-   IPS = inet_addr(Conn_Between_Hosts[Conn_Pointer].ip_source);
-   IPD = inet_addr(Conn_Between_Hosts[Conn_Pointer].ip_dest);
+   IPS = inet_addr(Conn_Between_Hosts[Conn_Pointer].source_ip);
+   IPD = inet_addr(Conn_Between_Hosts[Conn_Pointer].dest_ip);
 
-   MACD=Inet_MacFromIP(IPD);
+   MACD = Inet_MacFromIP(IPD);
 
    buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + TCP_HEADER );
 
@@ -307,7 +312,7 @@ void Interface_Sniff_KillConn(void)
 
    sock = Inet_OpenRawSock(Options.netiface);
 
-   MACD=Inet_MacFromIP(IPS);
+   MACD = Inet_MacFromIP(IPS);
 
    Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + TCP_HEADER );
 
@@ -459,18 +464,18 @@ void Interface_Sniff_Run(short mode)
                      break;
 
             case KEY_RETURN:
-                     if (Conn_Between_Hosts[Conn_Pointer].ip_source == NULL) break;   // no connections
+                     if (Conn_Between_Hosts[Conn_Pointer].source_ip == NULL) break;   // no connections
                      wmove(bottom_window, 0, 0);
                      if ( mode == PUBLICARP )
                          kill(Dopple_pid,SIGTERM);    // kill publicARP doppleganger...
 
                      kill(Illithid_pid, SIGUSR2);
-                     Interface_Sniff_Data_Run(Conn_Between_Hosts[Conn_Pointer].ip_source,
+                     Interface_Sniff_Data_Run(Conn_Between_Hosts[Conn_Pointer].source_ip,
                                               Conn_Between_Hosts[Conn_Pointer].source_port,
-                                              Conn_Between_Hosts[Conn_Pointer].ip_dest,
+                                              Conn_Between_Hosts[Conn_Pointer].dest_ip,
                                               Conn_Between_Hosts[Conn_Pointer].dest_port,
-                                              Conn_Between_Hosts[Conn_Pointer].mac_source,
-                                              Conn_Between_Hosts[Conn_Pointer].mac_dest,
+                                              Conn_Between_Hosts[Conn_Pointer].source_mac,
+                                              Conn_Between_Hosts[Conn_Pointer].dest_mac,
                                               Conn_Between_Hosts[Conn_Pointer].proto,
                                               Conn_Between_Hosts[Conn_Pointer].type,
                                               mode);
@@ -484,7 +489,7 @@ void Interface_Sniff_Run(short mode)
 
             case 'K':
             case 'k':
-                     if (Conn_Between_Hosts[Conn_Pointer].ip_source == NULL) break;   // no connections
+                     if (Conn_Between_Hosts[Conn_Pointer].source_ip == NULL) break;   // no connections
                      Interface_Sniff_KillConn();      // with TH_RST !  i'm too tired to implement FIN handshaking
                      Interface_Sniff_InitList();
                      break;
@@ -495,11 +500,11 @@ void Interface_Sniff_Run(short mode)
                         char source[40];
                         char dest[40];
                         char mesg[80];
-                        if (Conn_Between_Hosts[Conn_Pointer].ip_source == NULL) break;   // no connections
-                        snprintf(source, 40, " %s (%s) <-->", Inet_HostName(Conn_Between_Hosts[Conn_Pointer].ip_source),
-                                                              Conn_Between_Hosts[Conn_Pointer].ip_source);
-                        snprintf(dest, 40, " %s (%s)", Inet_HostName(Conn_Between_Hosts[Conn_Pointer].ip_dest),
-                                                       Conn_Between_Hosts[Conn_Pointer].ip_dest);
+                        if (Conn_Between_Hosts[Conn_Pointer].source_ip == NULL) break;   // no connections
+                        snprintf(source, 40, " %s (%s) <-->", Inet_HostName(Conn_Between_Hosts[Conn_Pointer].source_ip),
+                                                              Conn_Between_Hosts[Conn_Pointer].source_ip);
+                        snprintf(dest, 40, " %s (%s)", Inet_HostName(Conn_Between_Hosts[Conn_Pointer].dest_ip),
+                                                       Conn_Between_Hosts[Conn_Pointer].dest_ip);
                         snprintf(mesg, 80, "%s%s", source, dest);
                         Interface_PopUp(mesg);
                      }
@@ -511,6 +516,19 @@ void Interface_Sniff_Run(short mode)
                      Interface_Sniff_InitList();
                      break;
 
+            case 'X':
+            case 'x':
+                     Interface_Factory_Run();
+                     Interface_Redraw();
+                     break;
+
+#ifdef PERMIT_PLUGINS
+	         case 'P':
+   	      case 'p':
+      	            Interface_Plugins_Run();
+         	         break;
+#endif
+
             case 'A':
             case 'a':
                      if (mode == ARPBASED)
@@ -535,8 +553,12 @@ void Interface_Sniff_Run(short mode)
                         static char *help[] = {
                            "[qQ][F10] - quit",
                            "[return]  - sniff the selected connection",
-                           "[aA]      - enable/disable ACTIVE password collector",
+                           "[xX]      - Packet Forge",
+                           "[aA]      - enable/disable ACTIVE password collectors",
                            "[kK]      - kill the connection (be careful !)",
+#ifdef PERMIT_PLUGINS
+                       		"[pP]      - run a plugin",
+#endif
                            "[dD]      - resolve ip via DNS",
                            "[rR]      - refresh the list",
                            NULL};
