@@ -37,6 +37,7 @@
 #include "include/ec_doppleganger.h"
 #include "include/ec_illithid.h"
 #include "include/ec_buffer.h"
+#include "include/ec_error.h"
 
 #ifdef DEBUG
    #include "include/ec_debug.h"
@@ -237,12 +238,16 @@ void Interface_Sniff_Data_LogToFile(char proto, char *ipsource, int portsource,
       if (win_pointer == data_source_win)
       {
          file_source = fopen(filename, "a");
+         if (file_source == NULL)
+            Error_msg("ec_interface_sniff_data:%d fopen(%s) | ERRNO : %d | %s", filename, __LINE__, errno, strerror(errno));
          log_source = 1;
          mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10, "LOGGED");
       }
       else
       {
          file_dest = fopen(filename, "a");
+         if (file_dest == NULL)
+            Error_msg("ec_interface_sniff_data:%d fopen(%s) | ERRNO : %d | %s", filename, __LINE__, errno, strerror(errno));
          log_dest = 1;
          mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10, "LOGGED");
       }
@@ -369,7 +374,7 @@ void Interface_Sniff_Data_SniffData(char *source, char *dest, int portsource, in
    if (!Illithid_ToBeSniffed(source, portsource, dest, portdest, &data_from_illithid) || proto!=data_from_illithid.proto)
        return;
 
-   if (!strcmp(source, data_from_illithid.ip_source))
+   if (!strcmp(source, data_from_illithid.source_ip))
    {
       if (log_source) { write(fileno(file_source), &data_from_illithid.data, data_from_illithid.datasize); fflush(file_source);}
       if (!stop)
@@ -541,7 +546,6 @@ void Interface_Sniff_Data_Inject(char proto, char *app)
 void Interface_Sniff_Data_Filter(void)
 {
 
-   char answer;
    DROP_FILTER filter;
    DROP_FILTER null_filter;
 
@@ -549,15 +553,6 @@ void Interface_Sniff_Data_Filter(void)
    Debug_msg("Interface_Sniff_Data_Filter %d", inject);
 #endif
 
-
-   if (inject <= 0)  // 0 no inject  -1 no first packet
-   {
-      answer = Interface_PopUp("Do U really want to set up a filter on this connection (y/n)?");
-      Interface_Sniff_Data_Redraw();
-      if ((answer != 'y') && (answer != 'Y'))
-         return;
-   }
-
    memset(&filter, 0, sizeof(DROP_FILTER));
    memset(&null_filter, 0, sizeof(DROP_FILTER));
 
@@ -592,7 +587,7 @@ void Interface_Sniff_Data_Filter(void)
       else
       {
          Interface_Sniff_Data_ActiveFilter(1);
-         inject = 1;  // on exit the connection must be RSTted
+         if (filter.type != 'L') inject = 1;  // on exit the connection must be RSTted
       }
    }
 
@@ -820,7 +815,7 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
                   }
                   else
                   {
-                     Interface_PopUp("Filtering is only supported in ARP Based mode !!");
+                     Interface_PopUp("Active Filtering is only supported in ARP Based mode !!");
                      Interface_Sniff_Data_Redraw();
                   }
                   break;
@@ -859,7 +854,7 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
                      if (inject == 1 && proto == 'T')
                      {
                         char answer;
-                        answer = Interface_PopUp("If U exit now the connection will be ReSeTted!! continue (y/n)?");
+                        answer = Interface_PopUp("If U exit now the connection may be ReSeTted!! continue (y/n)?");
                         Interface_Sniff_Data_Redraw();
                         if ((answer != 'y') && (answer != 'Y'))
                            break;
