@@ -23,7 +23,6 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <time.h>
-#include <errno.h>
 
 #include "include/ec_main.h"
 #include "include/ec_error.h"
@@ -34,8 +33,8 @@
 #endif
 
 typedef struct {
-   char ip_source[16];
-   char ip_dest[16];
+   char source_ip[16];
+   char dest_ip[16];
    int source_port;
    int dest_port;
    char proto;
@@ -51,18 +50,16 @@ void LogToFile(SNIFFED_DATA *data);
 FILE * LogToFile_open_collect();
 void LogToFile_freelist(LOGGED_DATA *head);
 void LogToFile_close();
+void LogToFile_FilteredData(u_char * buf_ip);
 
 // -------------------------------
 
 FILE * LogToFile_open_collect()
 {
    FILE *fto;
-   time_t tt;
-   struct tm *dd;
    char filename[50];
-
-   tt = time(NULL);
-   dd = localtime(&tt);
+   time_t tt = time(NULL);
+   struct tm *dd = localtime(&tt);
 
    sprintf(filename, "%04d%02d%02d-collected-pass.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday);
    fto = fopen(filename, "a");
@@ -73,26 +70,24 @@ FILE * LogToFile_open_collect()
 
 void LogToFile(SNIFFED_DATA *data)
 {
-   time_t tt;
-   struct tm *dd;
    char filter[45];
    char cur_conn[45];
    char found = 0;
    LOGGED_DATA *index = head;
    LOGGED_DATA *ptr = index;
    LOGGED_DATA *current;
+   time_t tt = time(NULL);
+   struct tm *dd = localtime(&tt);
 
-   tt = time(NULL);
-   dd = localtime(&tt);
 
-   sprintf(filter, "%c%s%d%s%d", data->proto, data->ip_source, data->source_port, data->ip_dest, data->dest_port);
+   sprintf(filter, "%c%s%d%s%d", data->proto, data->source_ip, data->source_port, data->dest_ip, data->dest_port);
 
    if (head != NULL)
    {
       for(ptr = head; ptr != NULL; ptr = (LOGGED_DATA *)ptr->next)
       {
          index = ptr;
-         sprintf(cur_conn, "%c%s%d%s%d", index->proto, index->ip_source, index->source_port, index->ip_dest, index->dest_port);
+         sprintf(cur_conn, "%c%s%d%s%d", index->proto, index->source_ip, index->source_port, index->dest_ip, index->dest_port);
 
          if (!strcmp(filter, cur_conn))
          {
@@ -101,7 +96,7 @@ void LogToFile(SNIFFED_DATA *data)
             write(fileno(index->flog), data->data, data->datasize);
 
             if ( (data->flags & TH_RST) || (data->flags & TH_FIN) )
-            	fprintf(index->flog, "\n\n| CONNECTION CLOSED ON %02d:%02d:%02d |\n\n",  dd->tm_hour, dd->tm_min, dd->tm_sec);
+               fprintf(index->flog, "\n\n| CONNECTION CLOSED ON %02d:%02d:%02d |\n\n",  dd->tm_hour, dd->tm_min, dd->tm_sec);
 
             fflush(index->flog);
             return;
@@ -114,15 +109,15 @@ void LogToFile(SNIFFED_DATA *data)
       char logname[100];
 
       #ifdef DEBUG
-         Debug_msg("LogToFile - new log ! %c %s:%d - %s:%d ",  data->proto, data->ip_source, data->source_port, data->ip_dest, data->dest_port);
+         Debug_msg("LogToFile - new log ! %c %s:%d - %s:%d ",  data->proto, data->source_ip, data->source_port, data->dest_ip, data->dest_port);
       #endif
 
       current = (LOGGED_DATA *)calloc(1, sizeof(LOGGED_DATA));
       if (current == NULL)
          Error_msg("ec_logtofile:%d calloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
-      memcpy(current->ip_source, &data->ip_source, sizeof(data->ip_source));
-      memcpy(current->ip_dest, &data->ip_dest, sizeof(data->ip_dest));
+      memcpy(current->source_ip, &data->source_ip, sizeof(data->source_ip));
+      memcpy(current->dest_ip, &data->dest_ip, sizeof(data->dest_ip));
 
       current->source_port = data->source_port;
       current->dest_port = data->dest_port;
@@ -130,13 +125,15 @@ void LogToFile(SNIFFED_DATA *data)
 
       sprintf(logname, "%04d%02d%02d-%c-%s:%d-%s:%d.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday,
                         data->proto,
-                        data->ip_source,
+                        data->source_ip,
                         data->source_port,
-                        data->ip_dest,
+                        data->dest_ip,
                         data->dest_port
       );
 
       current->flog = fopen(logname, "a");
+      if (current->flog == NULL)
+         Error_msg("ec_logtofile:%d fopen(%s) | ERRNO : %d | %s", logname, __LINE__, errno, strerror(errno));
 
       write(fileno(current->flog), data->data, data->datasize);
       fflush(current->flog);
@@ -169,4 +166,56 @@ void LogToFile_freelist(LOGGED_DATA *cur)
 
 }
 
+
+void LogToFile_FilteredData(u_char * buf_ip)
+{
+   IP_header *ip;
+   UDP_header *udp;
+   TCP_header *tcp;
+   u_char *data = NULL;
+   short datalen = 0;
+   FILE *fto;
+   char logname[100];
+   time_t tt = time(NULL);
+   struct tm *dd = localtime(&tt);
+
+#ifdef DEBUG
+   Debug_msg("LogToFile_FilteredData");
+#endif
+
+   ip = (IP_header *) buf_ip;
+
+   if (ip->proto == IPPROTO_UDP)
+   {
+      udp = (UDP_header *) ((int)ip + ip->h_len * 4);
+      data = (char *)((int)udp + UDP_HEADER);
+      datalen = ntohs(udp->len) - UDP_HEADER;
+      sprintf(logname, "%04d%02d%02d-Filtered-U-%s:%d-", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday,
+                        int_ntoa(ip->source_ip),
+                        ntohs(udp->source));
+      sprintf(logname, "%s%s:%d.log", logname, int_ntoa(ip->dest_ip), ntohs(udp->dest) ); // damned static in inet_ntoa...
+   }
+   else if (ip->proto == IPPROTO_TCP)
+   {
+      tcp = (TCP_header *) ((int)ip + ip->h_len * 4);
+      data = (char *)((int)tcp + tcp->doff * 4);
+      datalen = (int)ip + ntohs(ip->t_len) - (int)data;
+      sprintf(logname, "%04d%02d%02d-Filtered-T-%s:%d-", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday,
+                        int_ntoa(ip->source_ip),
+                        ntohs(tcp->source));
+      sprintf(logname, "%s%s:%d.log", logname, int_ntoa(ip->dest_ip), ntohs(tcp->dest) ); // damned static in inet_ntoa...
+   }
+
+   if (data && datalen)
+   {
+      fto = fopen(logname, "a");
+      if (fto == NULL)
+         Error_msg("ec_logtofile:%d fopen(%s) | ERRNO : %d | %s", logname, __LINE__, errno, strerror(errno));
+      write(fileno(fto), data, datalen);
+      fflush(fto);
+      fclose(fto);
+   }
+
+}
+
 /* EOF */
