@@ -24,7 +24,7 @@
 #include <signal.h>
 #include <unistd.h>
 #ifdef LINUX
-	#define __USE_GNU		// for strsignal()
+   #define __USE_GNU    // for strsignal()
 #endif
 #include <string.h>
 
@@ -113,28 +113,31 @@ RETSIGTYPE Signal_WINCH(int sig)
 {
 
 #ifdef HAVE_NCURSES
-   if (data_source_win != NULL)
+   if (!Options.normal)
    {
-      #ifdef DEBUG
-         Debug_msg("Winching sniff data windows...");
-      #endif
-      Interface_Sniff_Data_Winch();
-   }
+      if (data_source_win != NULL)
+      {
+         #ifdef DEBUG
+            Debug_msg("Winching sniff data windows...");
+         #endif
+         Interface_Sniff_Data_Winch();
+      }
 #ifdef PERMIT_PLUGINS
-   else if (plugin_window != NULL)
-   {
-      #ifdef DEBUG
-         Debug_msg("Winching plugin windows...");
-      #endif
-      Interface_Plugins_Winch();
-   }
+      else if (plugin_window != NULL)
+      {
+         #ifdef DEBUG
+            Debug_msg("Winching plugin windows...");
+         #endif
+         Interface_Plugins_Winch();
+      }
 #endif
-   else
-   {
-      #ifdef DEBUG
-         Debug_msg("Winching windows...");
-      #endif
-      Interface_Winch();
+      else
+      {
+         #ifdef DEBUG
+            Debug_msg("Winching windows...");
+         #endif
+         Interface_Winch();
+      }
    }
 #endif
    signal(SIGWINCH, Signal_WINCH);
