@@ -26,7 +26,6 @@
 #include <time.h>
 #include <sys/time.h>
 #include <signal.h>
-#include <errno.h>
 
 #include "include/ec_main.h"
 #include "include/ec_error.h"
@@ -86,7 +85,7 @@ void Simple_HostList(void)
    Debug_msg("Simple_HostList");
 #endif
 
-   printf("Host in this LAN:\n\n");
+   printf("\nHost in this LAN:\n\n");
 
    for(j=0; j<number_of_hosts_in_lan; j++)
    {
@@ -151,7 +150,7 @@ void Simple_CheckForPoisoner(void)
 #endif
 
 
-   printf("Checking for poisoners...\n\n");
+   printf("\nChecking for poisoners...\n\n");
 
    SniffList = Inet_NoSniff();
 
@@ -377,8 +376,8 @@ void Simple_Run(void)
          Error_msg("Dest host %s (%s) not found !!", Host_Dest.name, Host_Dest.ip);
    }
 
-   if (!strcmp(Host_Source.ip, Host_Dest.ip) && strcmp(Host_Source.name, ""))
-      Error_msg("Source and Dest MUST be different !!");
+  	if ( !strcmp(Host_Source.ip, Host_Dest.ip) && strcmp(Host_Source.ip, "") )
+  		Error_msg("SOURCE and DEST IP address must be different !!");
 
    if (Options.arpsniff)
       if ( (!strcmp(Host_Source.ip, Inet_MyIPAddress())) || (!strcmp(Host_Dest.ip, Inet_MyIPAddress())) )
@@ -389,12 +388,7 @@ void Simple_Run(void)
    active_dissector = 0;
 
    if (Options.arpsniff)      // Doppleganger born...
-   {
-      char check[6];
-      Inet_GetMACfromString(Host_Dest.mac, check );   // check for valid mac
-      Inet_GetMACfromString(Host_Source.mac, check ); // check for valid mac
-      Dopple_pid = Doppleganger_Run(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
-   }
+	   Dopple_pid = Doppleganger_Run(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
 
    if (!Options.quiet) printf("\nPress 'h' for help...\n\n");
 
@@ -416,9 +410,6 @@ void Simple_Run(void)
    }
    else if (Options.macsniff)
    {
-      char check[6];
-      Inet_GetMACfromString(Host_Dest.mac, check );   // check for valid mac
-      Inet_GetMACfromString(Host_Source.mac, check ); // check for valid mac
       if (!Options.quiet) printf(" Sniffing (MAC based): %s <--> %s\n\n", Host_Dest.mac, Host_Source.mac);
       if (!Options.collect) Connection_Mode=0;
       Illithid_pid = Illithid_MACBased_GetConnections(Options.netiface, Host_Dest.mac, Host_Source.mac);
@@ -563,9 +554,9 @@ void Simple_Run(void)
                      if (logtofile == 2)
                      {
                         fprintf(logcollect, "\n\n%02d:%02d:%02d  %s:%d -> %s:%d\t\t%s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
-                                             Conn_Between_Hosts[i].ip_source,
+                                             Conn_Between_Hosts[i].source_ip,
                                              Conn_Between_Hosts[i].source_port,
-                                             Conn_Between_Hosts[i].ip_dest,
+                                             Conn_Between_Hosts[i].dest_ip,
                                              Conn_Between_Hosts[i].dest_port,
                                              Conn_Between_Hosts[i].type
                                              );
@@ -580,9 +571,9 @@ void Simple_Run(void)
                      if (!Options.quiet)
                      {
                         printf("\n\n%02d:%02d:%02d  %s:%d -> %s:%d\t\t%s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
-                              Conn_Between_Hosts[i].ip_source,
+                              Conn_Between_Hosts[i].source_ip,
                               Conn_Between_Hosts[i].source_port,
-                              Conn_Between_Hosts[i].ip_dest,
+                              Conn_Between_Hosts[i].dest_ip,
                               Conn_Between_Hosts[i].dest_port,
                               Conn_Between_Hosts[i].type
                               );
@@ -609,9 +600,9 @@ void Simple_Run(void)
                   {
                      case ASCII_VIEW:
                         printf("\n\n\n%02d:%02d:%02d  %s:%d -> %s:%d\n\n%s", dd->tm_hour, dd->tm_min, dd->tm_sec,
-                           data_from_illithid.ip_source,
+                           data_from_illithid.source_ip,
                            data_from_illithid.source_port,
-                           data_from_illithid.ip_dest,
+                           data_from_illithid.dest_ip,
                            data_from_illithid.dest_port,
                            Decodedata_GetAsciiData(data_from_illithid.data, data_from_illithid.datasize)
                         );
@@ -620,9 +611,9 @@ void Simple_Run(void)
                      case HEX_VIEW:
                         if (data_from_illithid.proto == 'T')
                            printf("\n\n%02d:%02d:%02d  %s:%d -> %s:%d | seq %lx ack %lx | flags %s |\n%s ", dd->tm_hour, dd->tm_min, dd->tm_sec,
-                              data_from_illithid.ip_source,
+                              data_from_illithid.source_ip,
                               data_from_illithid.source_port,
-                              data_from_illithid.ip_dest,
+                              data_from_illithid.dest_ip,
                               data_from_illithid.dest_port,
                               data_from_illithid.seq,
                               data_from_illithid.ack_seq,
@@ -631,9 +622,9 @@ void Simple_Run(void)
                            );
                         else
                            printf("\n\n%02d:%02d:%02d  %s:%d -> %s:%d | UDP |\n%s ", dd->tm_hour, dd->tm_min, dd->tm_sec,
-                              data_from_illithid.ip_source,
+                              data_from_illithid.source_ip,
                               data_from_illithid.source_port,
-                              data_from_illithid.ip_dest,
+                              data_from_illithid.dest_ip,
                               data_from_illithid.dest_port,
                               Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, 80)
                            );
