@@ -1,7 +1,11 @@
 
+// functions...
 extern void Dissector_Connections( char mode, short proto, u_char *data, void *data_to_ettercap, int Conn_Mode );
+extern int Dissector_StateMachine_GetStatus(CONNECTION *data_to_ettercap);
+extern int Dissector_StateMachine_SetStatus(CONNECTION *data_to_ettercap, char status);
 extern int Dissector_base64decode(char *bufplain, const char *bufcoded);
 
+// macros....
 #define FUNC_DISSECTOR(func) int func( u_char *data, void *vdata_to_ettercap, int Conn_Mode )
 
 #define ONLY_CONNECTION    CONNECTION *data_to_ettercap; \
@@ -14,6 +18,7 @@ extern int Dissector_base64decode(char *bufplain, const char *bufcoded);
    								sniff_data_to_ettercap = (SNIFFED_DATA *)vdata_to_ettercap
 
 
+// dissectors....
 extern FUNC_DISSECTOR(Dissector_ftp);      // 21
 #ifdef HAVE_OPENSSL
 extern FUNC_DISSECTOR(Dissector_ssh);      // 22
