@@ -9,7 +9,7 @@ extern int Inet_HostInLAN(void);
 extern SniffingHost * Inet_NoSniff(void);
 
 extern void Inet_PutMACinString(char *mac_string, unsigned char *MAC);
-extern void Inet_GetMACfromString(char *mac_string, unsigned char *MAC);
+extern int Inet_GetMACfromString(char *mac_string, unsigned char *MAC);
 extern int  Inet_CheckSwitch(void);
 
 // Following are architecture dependent !! implementations are in ./src/`uname`/ec_inet_`uname`.c
