@@ -193,14 +193,14 @@ typedef struct
 
 #ifdef HAVE_MACHINE_BIG
    #define ptohs(x) ( (u_short)                       \
-                      ((u_short)*((u_char *)p+1)<<8|  \
-                      (u_short)*((u_char *)p+0)<<0)   \
+                      ((u_short)*((u_char *)x+1)<<8|  \
+                      (u_short)*((u_char *)x+0)<<0)   \
                     )
 
-   #define ptohl(x) ( (u_int32_t)*((u_char *)p+3)<<24|  \
-                      (u_int32_t)*((u_char *)p+2)<<16|  \
-                      (u_int32_t)*((u_char *)p+1)<<8|   \
-                      (u_int32_t)*((u_char *)p+0)<<0    \
+   #define ptohl(x) ( (u_int32_t)*((u_char *)x+3)<<24|  \
+                      (u_int32_t)*((u_char *)x+2)<<16|  \
+                      (u_int32_t)*((u_char *)x+1)<<8|   \
+                      (u_int32_t)*((u_char *)x+0)<<0    \
                     )
 #endif
 
