@@ -3,7 +3,7 @@
 #endif
 
 #define DEVEL_RELEASE 0
-#define VERSION "0.4.2"
+#define VERSION "0.4.3"
 #define PROGRAM "ettercap"
 #define AUTHORS "ALoR & NaGA"
 
@@ -61,6 +61,7 @@ typedef struct options_list      // arguments passed on command line
    char broadping:1;
    char logtofile:1;
    char quiet:1;
+   char dontresolve:1;
    char netiface[10];
    char netmask[16];
 } OPTIONS;
@@ -69,17 +70,17 @@ extern OPTIONS Options;
 
 #define MAX_DATA 2000
 
-typedef struct data_connection   // data through the pipe with illithid
+typedef struct sniffed_data   // data through the pipe with illithid
 {
-   char ip_source[16];
-   char ip_dest[16];
-   int source_port;
-   int dest_port;
+   char source_ip[16];
+   char dest_ip[16];
+   short source_port;
+   short dest_port;
    u_long seq;
    u_long ack_seq;
    char flags;
    char proto;
-   int datasize;
+   short datasize;
    char data[MAX_DATA];     // FIXME: to be resized...
 } SNIFFED_DATA;
 
@@ -93,32 +94,25 @@ typedef struct {
 
 typedef struct connection        // connection list
 {
-   char ip_source[16];
-   char ip_dest[16];
-   char mac_source[20];
-   char mac_dest[20];
-   int source_port;
-   int dest_port;
+   char source_ip[16];
+   char dest_ip[16];
+   char source_mac[20];
+   char dest_mac[20];
+   short source_port;
+   short dest_port;
    u_long source_seq;
    u_long dest_seq;
    char flags;
    char proto;
-   int datalen;
+   short datalen;
    char status[8];
    char type[18];          // from /etc/services
    char user[30];          // pay attention on buffer overflow !!
    char pass[30];
-   char info[100];         // additional info... ( smb domain, http page ...)
+   char info[150];         // additional info... ( smb domain, http page ...)
 } CONNECTION;
 
 
-typedef struct {           // buffer structure (ec_buffer.c)
-   short size;
-   char *data;
-   struct BUFFER *next;
-} BUFFER;
-
-
 #define MAX_INJECT 1000  			// max number of injected chars
 #define MAX_FILTER 200	 			// max filter length
 
